cosmpy.protos.ibc.core.connection.v1 package — cosmpy documentation

# cosmpy.protos.ibc.core.connection.v1 package

## Submodules

## cosmpy.protos.ibc.core.connection.v1.connection_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.connection.v1.connection_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.connection.v1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.connection.v1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.ibc.core.connection.v1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc.Query

  Bases: `object`

  Query provides defines the gRPC querier service

  static ClientConnections(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Connection(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionClientState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionConsensusState(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Connections(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query provides defines the gRPC querier service

  ClientConnections(request, context)

    ClientConnections queries the connection paths associated with a client state.

  Connection(request, context)

    Connection queries an IBC connection end.

  ConnectionClientState(request, context)

    ConnectionClientState queries the client state associated with the connection.

  ConnectionConsensusState(request, context)

    ConnectionConsensusState queries the consensus state associated with the connection.

  Connections(request, context)

    Connections queries all the IBC connections of a chain.

class cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query provides defines the gRPC querier service

cosmpy.protos.ibc.core.connection.v1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.ibc.core.connection.v1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the ibc/connection Msg service.

  static ConnectionOpenAck(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionOpenConfirm(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionOpenInit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static ConnectionOpenTry(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the ibc/connection Msg service.

  ConnectionOpenAck(request, context)

    ConnectionOpenAck defines a rpc handler method for MsgConnectionOpenAck.

  ConnectionOpenConfirm(request, context)

    ConnectionOpenConfirm defines a rpc handler method for MsgConnectionOpenConfirm.

  ConnectionOpenInit(request, context)

    ConnectionOpenInit defines a rpc handler method for MsgConnectionOpenInit.

  ConnectionOpenTry(request, context)

    ConnectionOpenTry defines a rpc handler method for MsgConnectionOpenTry.

class cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the ibc/connection Msg service.

cosmpy.protos.ibc.core.connection.v1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents